=====
Qtile
=====

A full-featured, pure-Python tiling window manager
==================================================

:Website: http://www.qtile.org
:Source: https://github.com/qtile/qtile
:Documentation: http://qtile.readthedocs.org/en/latest/
:License: MIT License

Features
========

* Simple, small and extensible. It's easy to write your own layouts,
  widgets and commands.
* Configured in Python.
* Command shell that allows all aspects of Qtile to be managed and
  inspected.
* Complete remote scriptability - write scripts to set up workspaces,
  manipulate windows, update status bar widgets and more.
* Qtile's remote scriptability makes it one of the most thoroughly
  unit-tested window mangers around.

Current Release
===============

The current stable version of qtile is 0.7.0, released 2014-03-30.

Community
=========

Qtile is supported by a small (and growing!) but dedicated group of users. If
you need any help, please don't hesitate to fire off an email to our mailing
list or join us on IRC.

:Mailing List: http://groups.google.com/group/qtile-dev
:IRC: irc://irc.oftc.net:6667/qtile

Bug Tracker
===========

Please report any suggestions, feature requests, bug reports, or annoyances to
the Github `issue tracker`_.

.. _`issue tracker`: https://github.com/qtile/qtile/issues
